@@ -22,7 +22,7 @@ from .flags import (
 from .memory import empty
 from .utils import (
     broadcast_shapes, cast, complex_dtype, float_dtype, inspect_special_values,
-    isalias, izip_broadcast, pi, product, strshape, tointtuple, ufuncs)
+    isalias, pi, product, strshape, tointtuple, ufuncs, zip_broadcast)
 from .warnings import warn, PyOperatorsWarning
 
 __all__ = [
@@ -1435,7 +1435,7 @@ class SymmetricBandToeplitzOperator(Operator):
                 self.fplan.update_arrays(rbuffer, cbuffer)
                 self.bplan.update_arrays(cbuffer, rbuffer)
 
-                for x_, out_, kernel in izip_broadcast(x, out, self.kernel):
+                for x_, out_, kernel in zip_broadcast(x, out, self.kernel):
                     rbuffer[:lpad] = 0
                     rbuffer[lpad:lpad+self.nsamples] = x_
                     rbuffer[lpad+self.nsamples:] = 0
